@@ -1,15 +1,16 @@
-from typing import Iterator, List, Optional
+from abc import ABC, abstractmethod
+from typing import Iterator, List, Optional, Tuple
 
 from pipereport.telemetry.telemetry import Telemetry
 
 
-class BaseSink:
-
+class BaseSink(ABC):
     def __init__(self, *args, **kwargs):
-        self.attrs = kwargs 
+        self.attrs = kwargs
         self.name = self.required_field("name")
         self.telemetry = None
 
+    @abstractmethod
     def connect(self):
         raise NotImplementedError()
 
@@ -22,11 +23,25 @@ class BaseSink:
     def required_credential(self, credential_name: str):
         credentials = self.attrs.get("credentials", {})
         if credential_name not in credentials:
-            raise Exception(f"Credential '{credential_name}' is not specified for sink!")
+            raise Exception(
+                f"Credential '{credential_name}' is not specified for sink!"
+            )
         return credentials[credential_name]
 
+    @property
+    def telemetry_enabled(self):
+        return self.telemetry is not None
+
     def enable_telemetry(self, telemetry: Telemetry):
         self.telemetry = telemetry
 
-    def write_block(self, source_iterator: Iterator[str], object_id: str, blocksize: int=-1, columns: Optional[List[str]] = None):
+    @abstractmethod
+    def write_block(
+        self,
+        source_iterator: Iterator[Tuple],
+        object_id: str,
+        blocksize: int = -1,
+        columns: Optional[List[str]] = None,
+        sep: str = "\t",
+    ):
         raise NotImplementedError()
