@@ -1,15 +1,15 @@
-from typing import Dict, Iterator, List, Optional
+from abc import ABC, abstractmethod
+from typing import Dict, Iterator, List, Optional, Tuple
 
 from pipereport.base.sink import BaseSink
 from pipereport.telemetry.telemetry import Telemetry
 
 
-class BaseSource:
-
+class BaseSource(ABC):
     def __init__(self, *args, **kwargs):
         self.sinks: Dict[str, BaseSink] = {}
-        self.attrs = kwargs 
-        
+        self.attrs = kwargs
+
         self.type = self.required_field("type")
         self.name = self.required_field("name")
         self.sink_names = self.required_field("sink_names")
@@ -25,9 +25,11 @@ class BaseSource:
     def required_credential(self, credential_name: str):
         credentials = self.attrs.get("credentials", {})
         if credential_name not in credentials:
-            raise Exception(f"Credential '{credential_name}' is not specified for sink!")
+            raise Exception(
+                f"Credential '{credential_name}' is not specified for sink!"
+            )
         return credentials[credential_name]
-       
+
     def connect(self):
         raise NotImplementedError()
 
@@ -41,7 +43,14 @@ class BaseSource:
     def get_telemetry(self):
         return {sn: self.sinks[sn].telemetry for sn in self.sink_names}
 
-    def write_block(self, source_iterator: Iterator[str], object_id: str, blocksize: int = -1, columns: Optional[List[str]] = None):
+    def write_block(
+        self,
+        source_iterator: Iterator[Tuple],
+        object_id: str,
+        blocksize: int = -1,
+        columns: Optional[List[str]] = None,
+        sep: str = "\t",
+    ):
         sink_count = len(self.sink_names)
         if sink_count > 1:
             # TODO
@@ -51,8 +60,10 @@ class BaseSource:
                 source_iterator=source_iterator,
                 object_id=object_id,
                 blocksize=blocksize,
-                columns=columns
+                columns=columns,
+                sep=sep,
             )
 
+    @abstractmethod
     def run(self):
         raise NotImplementedError()
